@@ -32,6 +32,7 @@ struct _EphyAddBookmarkPopover {
   GtkPopover     parent_instance;
 
   char          *address;
+  gboolean       is_new_bookmark;
 
   GtkWidget     *grid;
   EphyHeaderBar *header_bar;
@@ -108,9 +109,27 @@ ephy_add_bookmark_popover_class_init (EphyAddBookmarkPopoverClass *klass)
   g_object_class_install_properties (object_class, LAST_PROP, obj_properties);
 }
 
+static void
+ephy_add_bookmark_popover_closed_cb (GtkPopover *popover,
+                                     gpointer    user_data)
+{
+  EphyBookmarksManager *manager;
+
+  g_assert (EPHY_IS_ADD_BOOKMARK_POPOVER (popover));
+
+  manager = ephy_shell_get_bookmarks_manager (ephy_shell_get_default ());
+
+  ephy_bookmarks_manager_save_to_file_async (manager, NULL,
+                                             ephy_bookmarks_manager_save_to_file_warn_on_error_cb,
+                                             NULL);
+}
+
 static void
 ephy_add_bookmark_popover_init (EphyAddBookmarkPopover *self)
 {
+  g_signal_connect (self, "closed",
+                    G_CALLBACK (ephy_add_bookmark_popover_closed_cb),
+                    NULL);
 }
 
 GtkWidget *
@@ -172,14 +191,14 @@ void
 ephy_add_bookmark_popover_show (EphyAddBookmarkPopover *self)
 {
   EphyBookmarksManager *manager;
-  GtkWidget *location_entry;
-  EphyWindow *window;
-  EphyEmbed *embed;
   EphyBookmark *bookmark;
+  EphyWindow *window;
+  EphyLocationEntry *location_entry;
+  EphyEmbed *embed;
   const char *address;
 
   manager = ephy_shell_get_bookmarks_manager (ephy_shell_get_default ());
-  location_entry = GTK_WIDGET (ephy_header_bar_get_title_widget (self->header_bar));
+  location_entry = EPHY_LOCATION_ENTRY (ephy_header_bar_get_title_widget (self->header_bar));
   window = ephy_header_bar_get_window (self->header_bar);
   embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
 
@@ -192,20 +211,22 @@ ephy_add_bookmark_popover_show (EphyAddBookmarkPopover *self)
                                   g_sequence_new (g_free));
 
     ephy_bookmarks_manager_add_bookmark (manager, bookmark);
-    ephy_location_entry_set_bookmark_icon_state (EPHY_LOCATION_ENTRY (location_entry),
+    ephy_location_entry_set_bookmark_icon_state (location_entry,
                                                  EPHY_LOCATION_ENTRY_BOOKMARK_ICON_BOOKMARKED);
+    g_object_unref (bookmark);
   }
 
   g_signal_connect_object (manager, "bookmark-removed",
-                         G_CALLBACK (ephy_add_bookmark_popover_update_bookmarked_status_cb),
-                         self,
-                         G_CONNECT_SWAPPED);
+                           G_CALLBACK (ephy_add_bookmark_popover_update_bookmarked_status_cb),
+                           self,
+                           G_CONNECT_SWAPPED);
 
   if (self->grid)
     gtk_widget_destroy (self->grid);
   self->grid = ephy_bookmark_properties_grid_new (bookmark,
                                                   EPHY_BOOKMARK_PROPERTIES_GRID_TYPE_POPOVER,
                                                   GTK_WIDGET (self));
+
   gtk_container_add (GTK_CONTAINER (self), self->grid);
   gtk_popover_set_default_widget (GTK_POPOVER (self),
                                   ephy_bookmark_properties_grid_get_add_tag_button (EPHY_BOOKMARK_PROPERTIES_GRID (self->grid)));
