@@ -465,7 +465,6 @@ ephy_notebook_constructed (GObject *object)
   EphyNotebook *notebook = EPHY_NOTEBOOK (object);
   GtkWidget *hbox;
   GtkWidget *button;
-  GtkWidget *popover;
 
   G_OBJECT_CLASS (ephy_notebook_parent_class)->constructed (object);
 
@@ -489,9 +488,9 @@ ephy_notebook_constructed (GObject *object)
   gtk_widget_show (button);
 
   notebook->tab_menu = g_menu_new ();
-  popover = gtk_popover_new (button);
-  gtk_popover_bind_model (GTK_POPOVER (popover), G_MENU_MODEL (notebook->tab_menu), "win");
-  gtk_menu_button_set_popover (GTK_MENU_BUTTON (button), popover);
+  /* Remove this when popover menus become scrollable. */
+  gtk_menu_button_set_use_popover (GTK_MENU_BUTTON (button), FALSE);
+  gtk_menu_button_set_menu_model (GTK_MENU_BUTTON (button), G_MENU_MODEL (notebook->tab_menu));
 }
 
 static void
@@ -560,6 +559,10 @@ ephy_notebook_rebuild_tab_menu (EphyNotebook *notebook)
   const char *text;
   char *ellipsized_text;
   int num_pages;
+  GtkWidget *window;
+  GActionGroup *group;
+  GAction *action;
+  gint current_page;
 
   g_menu_remove_all (notebook->tab_menu);
 
@@ -570,11 +573,24 @@ ephy_notebook_rebuild_tab_menu (EphyNotebook *notebook)
     text = get_nth_tab_label_text (GTK_NOTEBOOK (notebook), i);
     ellipsized_text = ellipsize_tab_label (text);
     item = g_menu_item_new (ellipsized_text, NULL);
-    g_menu_item_set_action_and_target (item, "show-tab", "u", (guint)i, NULL);
+    g_menu_item_set_action_and_target (item, "win.show-tab", "u", (guint)i, NULL);
     g_menu_append_item (notebook->tab_menu, item);
     g_free (ellipsized_text);
     g_object_unref (item);
   }
+
+  current_page = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook));
+  if (current_page < 0)
+    return;
+
+  window = gtk_widget_get_toplevel (GTK_WIDGET (notebook));
+  group = gtk_widget_get_action_group (window, "win");
+  /* Is window being destroyed? */
+  if (group == NULL)
+    return;
+
+  action = g_action_map_lookup_action (G_ACTION_MAP (group), "show-tab");
+  g_simple_action_set_state (G_SIMPLE_ACTION (action), g_variant_new_uint32 ((guint32)current_page));
 }
 
 static void
