@@ -29,11 +29,11 @@
 #include "ephy-profile-utils.h"
 #include "ephy-shell.h"
 
-#include <string.h>
-#include <glib/gi18n.h>
 #include <gio/gio.h>
 #include <gio/gdesktopappinfo.h>
+#include <glib/gi18n.h>
 #include <libsoup/soup.h>
+#include <string.h>
 
 struct _EphySearchProvider {
   GApplication parent_instance;
@@ -42,7 +42,6 @@ struct _EphySearchProvider {
   GCancellable             *cancellable;
 
   GSettings                *settings;
-  EphyHistoryService       *history_service;
   EphyBookmarksManager     *bookmarks_manager;
   EphyCompletionModel      *model;
 };
@@ -278,15 +277,18 @@ launch_search (EphySearchProvider *self,
                char              **terms,
                guint               timestamp)
 {
-  char *search_string, *url_search, *query_param, *effective_url;
+  char *search_string;
+  const char *address_search;
+  char *query_param;
+  char *effective_url;
+  char *default_name;
+  EphyEmbedShell *shell;
+  EphySearchEngineManager *search_engine_manager;
 
-  url_search = g_settings_get_string (self->settings, EPHY_PREFS_KEYWORD_SEARCH_URL);
-
-  if (url_search == NULL || url_search[0] == '\0') {
-    g_free (url_search);
-
-    url_search = g_strdup (_("https://duckduckgo.com/?q=%s&amp;t=epiphany"));
-  }
+  shell = ephy_embed_shell_get_default ();
+  search_engine_manager = ephy_embed_shell_get_search_engine_manager (shell);
+  default_name = ephy_search_engine_manager_get_default_engine (search_engine_manager);
+  address_search = ephy_search_engine_manager_get_address (search_engine_manager, default_name);
 
   search_string = g_strjoinv (" ", terms);
   query_param = soup_form_encode ("q", search_string, NULL);
@@ -295,15 +297,15 @@ launch_search (EphySearchProvider *self,
 #pragma GCC diagnostic ignored "-Wformat-nonliteral"
   /* Format string under control of user input... but gsettings is trusted input. */
   /* + 2 here is getting rid of 'q=' */
-  effective_url = g_strdup_printf (url_search, query_param + 2);
+  effective_url = g_strdup_printf (address_search, query_param + 2);
 #pragma GCC diagnostic pop
 
   launch_uri (effective_url, timestamp);
 
   g_free (query_param);
-  g_free (url_search);
   g_free (effective_url);
   g_free (search_string);
+  g_free (default_name);
 }
 
 static gboolean
@@ -350,6 +352,7 @@ static void
 ephy_search_provider_init (EphySearchProvider *self)
 {
   char *filename;
+  EphyEmbedShell *shell = ephy_embed_shell_get_default ();
 
   g_application_set_flags (G_APPLICATION (self), G_APPLICATION_IS_SERVICE);
 
@@ -369,9 +372,9 @@ ephy_search_provider_init (EphySearchProvider *self)
   self->settings = g_settings_new (EPHY_PREFS_SCHEMA);
 
   filename = g_build_filename (ephy_dot_dir (), EPHY_HISTORY_FILE, NULL);
-  self->history_service = ephy_history_service_new (filename, TRUE);
   self->bookmarks_manager = ephy_bookmarks_manager_new ();
-  self->model = ephy_completion_model_new (self->history_service, self->bookmarks_manager);
+  self->model = ephy_completion_model_new (ephy_embed_shell_get_global_history_service (shell),
+                                           self->bookmarks_manager);
   g_free (filename);
 
   self->cancellable = g_cancellable_new ();
@@ -430,7 +433,6 @@ ephy_search_provider_dispose (GObject *object)
   g_clear_object (&self->settings);
   g_clear_object (&self->cancellable);
   g_clear_object (&self->model);
-  g_clear_object (&self->history_service);
   g_clear_object (&self->bookmarks_manager);
 
   G_OBJECT_CLASS (ephy_search_provider_parent_class)->dispose (object);
